Cheshire3 Object Model - Workflow
=================================

.. _objects-workflow-api:

API
---

.. autoclass:: cheshire3.baseObjects.Workflow
   :members:


.. _objects-workflow-implementations:

Implementations
---------------

The following implementations are included in the distribution by default:

.. autoclass:: cheshire3.workflow.SimpleWorkflow

.. autoclass:: cheshire3.workflow.CachingWorkflow
